package com.jz.common.constant;

import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

@ApiModel(value = "接口返回对象", description = "接口返回对象")
@JsonInclude(JsonInclude.Include.NON_NULL)
public class JsonResult<T> implements Serializable {

    private static final long serialVersionUID = 7988584286944000677L;
    /**
     * 返回代码
     */
    @ApiModelProperty(value = "返回代码")
    private String code;

    /**
     * 返回处理消息
     */
    @ApiModelProperty(value = "返回处理消息")
    private String message;

    /**
     * 返回数据对象 data
     */
    @ApiModelProperty(value = "返回数据对象")
    private T data;

    public JsonResult() {
        this.setCode(ResultCode.SUCCESS);
        this.setMessage("成功！");
    }

    public JsonResult(ResultCode code) {
        this.setCode(code);
        this.setMessage(code.msg());
    }

    public JsonResult(ResultCode code, String message) {
        this.setCode(code);
        this.setMessage(message);
    }

    public JsonResult(ResultCode code, T data) {
        this.setCode(code);
        this.setMessage(code.msg());
        this.setData(data);
    }

    public JsonResult(ResultCode code, String message, T data) {
        this.setCode(code);
        this.setMessage(message);
        this.setData(data);
    }

    public JsonResult(T data) {
        this.setCode(ResultCode.SUCCESS);
        this.setMessage("成功！");
        this.setData(data);
    }

    public JsonResult(com.jz.dmp.agent.ResultCode code, String message) {
        this.setCodes(code);
        this.setMessage(message);
    }

    public static JsonResult<Object> ok() {
        JsonResult<Object> result = new JsonResult<>();
        result.setCode(ResultCode.SUCCESS);
        result.setMessage("成功！");
        return result;
    }

    public static JsonResult<Object> ok(String message) {
        JsonResult<Object> result = new JsonResult<>();
        result.setCode(ResultCode.SUCCESS);
        result.setMessage(message);
        return result;
    }

    public static JsonResult<Object> ok(Object data) {
        JsonResult<Object> result = new JsonResult<>();
        result.setCode(ResultCode.SUCCESS);
        result.setMessage("成功！");
        result.setData(data);
        return result;
    }

    public static JsonResult<Object> error() {
        JsonResult<Object> result = new JsonResult<>();
        result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        result.setMessage(ResultCode.INTERNAL_SERVER_ERROR.msg());
        return result;
    }

    public static JsonResult<Object> error(String message) {
        JsonResult<Object> result = new JsonResult<>();
        result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        result.setMessage(message);
        return result;
    }

    public static JsonResult<Object> error(ResultCode code, String message) {
        JsonResult<Object> result = new JsonResult<>();
        result.setCode(code);
        result.setMessage(message);
        return result;
    }

    public void setCodes(com.jz.dmp.agent.ResultCode code) {
        this.code = code.val();
    }

    public String getCode() {
        return code;
    }

    public void setCode(ResultCode code) {
        this.code = code.val();
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

}
