package com.jz.dmp.modules.controller.dataOperation;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListReq;
import com.jz.dmp.modules.controller.dataOperation.bean.DataDevTaskListDto;
import com.jz.dmp.modules.controller.dataOperation.bean.DataDevTaskListReq;
import com.jz.dmp.modules.service.DmpDevelopTaskService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 数据运维-数据开发任务
 *
 * @author Bellamy
 * @since 2021-01-13 10:56:18
 */
@RestController
@RequestMapping("/dataDevTask")
@Api(tags = "数据运维-数据开发任务")
public class DmpDevTaskController {

    @Autowired
    private DmpDevelopTaskService dmpDevelopTaskService;

    /**
     * 列表分页查询
     *
     * @return
     * @author Bellamy
     * @since 2021-01-05
     */
    @ApiOperation(value = "列表分页查询", notes = "列表分页查询")
    @PostMapping(value = "/listPage")
    public PageInfoResponse<DataDevTaskListDto> getDevTaskListPage(@RequestBody @Validated DataDevTaskListReq req, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<DataDevTaskListDto> pageInfo = new PageInfoResponse<DataDevTaskListDto>();
        if (StringUtils.isEmpty(req.getProjectId())) {
            pageInfo.setMessage("项目id不能为空！");
            pageInfo.setCode(ResultCode.PARAMS_ERROR);
            return pageInfo;
        }
        try {
            pageInfo = dmpDevelopTaskService.queryDevTaskListPage(req);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 执行任务
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "执行", notes = "执行")
    @GetMapping(value = "/runTask")
    @ApiImplicitParam(name = "taskId", value = "任务id")
    public JsonResult runTaskByTaskId(@RequestParam(value = "taskId") String taskId) throws Exception {
        if (StringUtils.isEmpty(taskId)) {
            return new JsonResult(ResultCode.PARAMS_ERROR,"任务id不能为空！");
        }
        JsonResult list = dmpDevelopTaskService.runTaskByTaskId(taskId);
        return list;
    }
}
