package com.jz.dmp.modules.service;


import com.jz.common.constant.JsonResult;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceListReq;
import com.jz.dmp.modules.controller.DataIntegration.bean.DmpSyncingDatasourceReq;
import com.jz.dmp.modules.model.DmpSyncingDatasource;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * 数据源配置(DmpSyncingDatasource)表服务接口
 *
 * @author Bellamy
 * @since 2020-12-24 14:09:59
 */
public interface DmpSyncingDatasourceService {

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    DmpSyncingDatasource queryById(Integer id);

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    List<DmpSyncingDatasource> queryAllByLimit(int offset, int limit);

    /**
     * 新增数据
     *
     * @param dmpSyncingDatasource 实例对象
     * @return 实例对象
     */
    DmpSyncingDatasource insert(DmpSyncingDatasource dmpSyncingDatasource);

    /**
     * 修改数据
     *
     * @param dmpSyncingDatasource 实例对象
     * @return 实例对象
     */
    DmpSyncingDatasource update(DmpSyncingDatasource dmpSyncingDatasource);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    boolean deleteById(Integer id);

    PageInfoResponse<DataSourceListDto> queryDataSourceListPage(DataSourceListReq req, HttpServletRequest httpRequest) throws Exception;

    /**
     * 批量删除数据源
     *
     * @return
     * @author Bellamy
     */
    JsonResult delDataSourceById(String datasourceId) throws Exception;

    /**
     * 获取数据源类型-下拉框
     *
     * @return
     * @author Bellamy
     */
    JsonResult queryDatasourceType() throws Exception;

    /**
     * 新增获取数据源类型
     *
     * @return
     * @author Bellamy
     */
    JsonResult queryGroupDatasourceType() throws Exception;

    /**
     * 保存数据源
     *
     * @return
     * @author Bellamy
     */
    JsonResult addDatasourceInfo(DmpSyncingDatasourceReq saveBody) throws Exception;

    /**
     * 测试连通性
     *
     * @return
     * @author Bellamy
     */
    JsonResult testConnection(DmpSyncingDatasourceReq saveBody) throws Exception;

    /**
     * 编辑数据源，根据id查询数据回显
     *
     * @return
     * @author Bellamy
     */
    JsonResult selectDataSourceInfoById(Map map) throws Exception;

    /**
     * 编辑数据源
     *
     * @return
     * @author Bellamy
     */
    JsonResult updateDatasourceById(DmpSyncingDatasourceReq saveBody) throws Exception;

    List<DmpSyncingDatasource> findListByParams(DmpSyncingDatasource ds) throws Exception;

    /**
     * 获取数据源类型输入框属性
     *
     * @return
     * @author Bellamy
     */
    JsonResult selectDatasourceTypeAttrById(String datasourceTypeId) throws Exception;
}